==> haskell-vector-hashtables-0.1.1.3-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-hashtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-hashtables
version:              0.1.1.3
visibility:           public
id:                   vector-hashtables-0.1.1.3-KH5t7m6pov51ZONCCrrIG3
key:                  vector-hashtables-0.1.1.3-KH5t7m6pov51ZONCCrrIG3
license:              BSD-3-Clause
copyright:            2016-2023 klapaucius, swamp_agr
maintainer:           klapaucius, swamp_agr, ArtemPelenitsyn
author:               klapaucius
homepage:             https://github.com/klapaucius/vector-hashtables#readme
synopsis:             Efficient vector-based mutable hashtables implementation.
description:
    This package provides efficient vector-based hashtable implementation similar to .NET Generic Dictionary implementation (at the time of 2015).

    See "Data.Vector.Hashtables" for documentation.

category:             Data
abi:                  4741fa33eccadf0cac87d4a5ec6497b3
exposed:              True
exposed-modules:
    Data.Primitive.PrimArray.Utils Data.Vector.Hashtables
    Data.Vector.Hashtables.Internal
    Data.Vector.Hashtables.Internal.Mask

import-dirs:          /usr/lib/ghc-9.0.2/site-local/vector-hashtables-0.1.1.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/vector-hashtables-0.1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-hashtables
hs-libraries:         HSvector-hashtables-0.1.1.3-KH5t7m6pov51ZONCCrrIG3
depends:
    base-4.15.1.0 hashable-1.4.2.0-ACOKJtOF9viKWyhESTEaY8
    primitive-0.7.4.0-GEmDUJD22mHBwXDxBmNo7T
    vector-0.13.0.0-AvCgqYhQ3vmCYiPnKivqd

haddock-interfaces:
    /usr/share/doc/haskell-vector-hashtables/html/vector-hashtables.haddock

haddock-html:         /usr/share/doc/haskell-vector-hashtables/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-hashtables-0.1.1.3-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-hashtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-hashtables
version:              0.1.1.3
visibility:           public
id:                   vector-hashtables-0.1.1.3-3ZdJGS37Qfq9PQOouhjrVl
key:                  vector-hashtables-0.1.1.3-3ZdJGS37Qfq9PQOouhjrVl
license:              BSD-3-Clause
copyright:            2016-2023 klapaucius, swamp_agr
maintainer:           klapaucius, swamp_agr, ArtemPelenitsyn
author:               klapaucius
homepage:             https://github.com/klapaucius/vector-hashtables#readme
synopsis:             Efficient vector-based mutable hashtables implementation.
description:
    This package provides efficient vector-based hashtable implementation similar to .NET Generic Dictionary implementation (at the time of 2015).

    See "Data.Vector.Hashtables" for documentation.

category:             Data
abi:                  a943e5d7d1443e86ff13be3b55f40427
exposed:              True
exposed-modules:
    Data.Primitive.PrimArray.Utils Data.Vector.Hashtables
    Data.Vector.Hashtables.Internal
    Data.Vector.Hashtables.Internal.Mask

import-dirs:          /usr/lib/ghc-9.0.2/site-local/vector-hashtables-0.1.1.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/vector-hashtables-0.1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-hashtables
hs-libraries:         HSvector-hashtables-0.1.1.3-3ZdJGS37Qfq9PQOouhjrVl
depends:
    base-4.15.1.0 hashable-1.4.2.0-7UVOGh0pBDMGm1lHduVYaK
    primitive-0.7.4.0-I1O4QOaB8j8Amk16YP3J6x
    vector-0.13.0.0-8c7RlyjNINpFLowVEJNlQ1

haddock-interfaces:
    /usr/share/doc/haskell-vector-hashtables/html/vector-hashtables.haddock

haddock-html:         /usr/share/doc/haskell-vector-hashtables/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
